@@ -19,17 +19,17 @@ class EWAHPipedriveOperator(EWAHBaseOperator):
     def __init__(
         self,
         pipedrive_object: Optional[str] = None,
-        additinal_params: Optional[dict] = None,
+        additional_params: Optional[dict] = None,
         *args,
         **kwargs
     ) -> None:
         self.pipedrive_object = pipedrive_object or kwargs.get("target_table_name")
-        self.additinal_params = additinal_params or {}
+        self.additional_params = additional_params or {}
         super().__init__(*args, **kwargs)
 
     def ewah_execute(self, context: dict) -> None:
         self.log.info("Fetching data from Pipedrive for {self.pipedrive_object}...")
         for batch in self.source_hook.get_data_in_batches(
-            self.pipedrive_object, **self.additinal_params
+            self.pipedrive_object, **self.additional_params
         ):
             self.upload_data(batch)
